/*
Hibernus for MSP430FR5739:

Hibernus: Software-based approach to intelligently hibernate and restore the system's state
in response to a power failure. This software exploits an external comparator.

Citation: If you are using this code for your research please cite:

[1]	D. Balsamo, A. S. Weddell, G. V. Merrett, B. M. Al-Hashimi, D. Brunelli and L. Benini,
	"Hibernus: Sustaining Computation During Intermittent Supply for Energy-Harvesting Systems,"
	in IEEE Embedded Systems Letters, vol. 7, no. 1, pp. 15-18, March 2015.

[2]	D. Balsamo; A. Weddell; A. Das; A. Arreola; D. Brunelli; B. Al-Hashimi; G. Merrett; L. Benini,
	"Hibernus++: A Self-Calibrating and Adaptive System for Transiently-Powered Embedded Devices,"
	in IEEE Transactions on Computer-Aided Design of Integrated Circuits and Systems , vol.PP, no.99, pp.1-1

This research has been supported by the University of Southampton and the University of Bologna.
Copyright 2016, Domenico Balsamo, All rights reserved.
25/05/2016
*/

#include <msp430.h> 
#include "hibernation.h" //Include Hibernus Library

/*
 * main.c
 */

//Main function for binary counter
void Set_Binary_value (unsigned int v);
unsigned int value=0;

int main(void){

	//For Debugging: System active
	P2DIR |= BIT6;
	P2OUT |= BIT6;

	WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer

    Hibernus();

    //Main code goes here

    int i;

    while(1){

		for(i=0;i<256;i++){
			Set_Binary_value(i);
			__delay_cycles(1000000);
		}

    }

 }

void Set_Binary_value (unsigned int v){

	 value=v;

	 //setting LEDs
     PJOUT &= ~(BIT0);
     PJOUT &= ~(BIT1);
     PJOUT &= ~(BIT2);
   	 PJOUT &= ~(BIT3);
     P3OUT &= ~(BIT4);
     P3OUT &= ~(BIT5);
     P3OUT &= ~(BIT6);
     P3OUT &= ~(BIT7);

     PJOUT |= (BIT0 & (value & 0x0001));
     PJOUT |= (BIT1 & (value & 0x0002));
     PJOUT |= (BIT2 & (value & 0x0004));
     PJOUT |= (BIT3 & (value & 0x0008));
     P3OUT |= (BIT4 & (value & 0x0010));
     P3OUT |= (BIT5 & (value & 0x0020));
     P3OUT |= (BIT6 & (value & 0x0040));
     P3OUT |= (BIT7 & (value & 0x0080));

 }
